@@ -24,7 +24,7 @@ winsorize <- function(x, thresh = c(0.05, 0.95), na.rm = FALSE) {
   i <- which(x >= cut_point_top)
   x[i] <- cut_point_top
   attr(x, "thresh") <- thresh
-  return(x)
+  x
 }
 
 ####################################################################
@@ -58,7 +58,7 @@ outlier_zscore <- function(x, thresh = 3, mad = FALSE) {
     ret <- !abs(x - calc) <= z
     attr(ret, "values") <- data.frame(z = z, mad = mad, med = calc)
   }
-  return(ret)
+  ret
 }
 
 ####################################################################
@@ -82,7 +82,7 @@ outlier_zscore <- function(x, thresh = 3, mad = FALSE) {
 #' p <- outlier_zscore_plot(dft, Fare, Pclass, thresh = c(3, 5))
 #' plot(p)
 #' attr(p, "z_values")
-#' head(attr(p, "labels"))
+#' head(attr(p, "z_labels"))
 #' @export
 outlier_zscore_plot <- function(df, var, group = NULL,
                                 thresh = c(2, 3, 5),
@@ -153,9 +153,9 @@ outlier_zscore_plot <- function(df, var, group = NULL,
     ))
   }
 
-  attr(p, "labels") <- select(df, !!var, one_of(paste0("Z-", thresh)), starts_with("outlier_"))
+  attr(p, "z_labels") <- select(df, !!var, one_of(paste0("Z-", thresh)), starts_with("outlier_"))
   attr(p, "z_values") <- zs
-  return(p)
+  p
 }
 
 ####################################################################
